@@ -162,7 +162,11 @@ static char sccsid[] = "@(#)syslogd.c	5.27 (Berkeley) 10/10/88";
 #else
 #include <sys/msgbuf.h>
 #endif
+#ifdef	LINUX
+#include <linux/uio.h>
+#else
 #include <sys/uio.h>
+#endif
 #include <sys/un.h>
 #include <sys/time.h>
 #include <sys/resource.h>
@@ -178,7 +182,7 @@ static char sccsid[] = "@(#)syslogd.c	5.27 (Berkeley) 10/10/88";
 #define	CTTY	"/dev/console"
 char	*LogName = "/dev/log";
 char	*ConfFile = "/etc/syslog.conf";
-char	*PidFile = "/etc/syslog.pid";
+char	*PidFile = "/var/run/syslogd.pid";
 char	ctty[] = CTTY;
 char	**parts;
 
@@ -321,7 +325,7 @@ int	MarkSeq = 0;		/* mark sequence number */
 
 extern	int errno, sys_nerr;
 extern	char *sys_errlist[];
-extern	char *ctime(), *index(), *calloc();
+extern	char *ctime(), *index();
 
 /* Function prototypes. */
 int main(int argc, char **argv);
